Editor
======

To be able to program Stoq efficiently you need to know about an editor.

This part of the documentation explains how you use and configure your editor
to make it work well with Stoq development practicies.

vim
---

Learning how to use VIM:

 * `Vim Introduction and Tutorial - IMHO <http://blog.interlinked.org/tutorials/vim_tutorial.html>`__

emacs
-----

XXX
